Class: Hone::Patterns::SelectFirst

Inherits:
Base
  • Object
show all
Defined in:
lib/hone/patterns/select_first.rb

Overview

Pattern: array.select { }.first -> array.detect { } / array.find { }

select.first iterates the entire array building a new array, then takes first. detect/find stops iteration as soon as a match is found.

Instance Attribute Summary

Attributes inherited from Base

#findings

Instance Method Summary collapse

Methods inherited from Base

#add_finding, inherited, #initialize, scan_file

Constructor Details

This class inherits a constructor from Hone::Patterns::Base

Instance Method Details

#visit_call_node(node) ⇒ Object



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
# File 'lib/hone/patterns/select_first.rb', line 13

def visit_call_node(node)
  super

  # Look for: .first where receiver is .select with a block
  return unless node.name == :first && node.arguments.nil?

  receiver = node.receiver
  return unless receiver.is_a?(Prism::CallNode)
  return unless receiver.name == :select && block_attached?(receiver)

  add_finding(
    node,
    message: "Use `.detect { }` or `.find { }` instead of `.select { }.first` to stop at first match",
    speedup: "Avoids iterating entire array and intermediate array allocation"
  )
end